from django.forms import *
from app.models import Event, Request, User, Zone
from datetime import datetime
from ldap_inp import LdapEleve, LdapClub


class EventForm(ModelForm):
    class Meta:
        model = Event
        exclude = ["creator", "admin_comment"]
        #TODO Pour que les champs starts et ends soient deja remplis, il faut que le format de la date soit DD-MM-YYYY
        widgets = {
            "start": DateInput(attrs={"type": "date"}),
            "end": DateInput(attrs={"type": "date"}),
            "description": Textarea(attrs={"placeholder": "Description de l'évènement"}),
        }


class RequestForm(ModelForm):
    class Meta:
        model = Request
        exclude = ["creator", "admin_comment", "state"]
        widgets = {
            "start": DateInput(attrs={"type": "date"}),
            "end": DateInput(attrs={"type": "date"}),
            "zones": CheckboxSelectMultiple(attrs={"placeholder": "Choisissez une ou plusieurs zones"}),
            "authorized": Textarea(attrs={"placeholder": "Nom et prénoms des utilisateurs autoriés, séparés par des virgules"}),
            "creator_comment": Textarea(attrs={"placeholder": "Commentaire supplémentaire"}),
            "club": Select(attrs={"placeholder": "Choisissez un club"}),
            "contact_phone": TextInput(attrs={"placeholder": "Numéro de téléphone (si plusieurs, séparés par des virgules))"}),
            "contact_mail": EmailInput(attrs={"placeholder": "Adresse mail"}),
        }
        event = ModelChoiceField(
            queryset=Event.objects.filter(end__gte=datetime.now()),
            empty_label="Choisissez un évènement",
            label="Évènement",
        )

